about summary refs log tree commit diff stats
path: root/src/xmpp/connection.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/xmpp/connection.c')
-rw-r--r--src/xmpp/connection.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/xmpp/connection.c b/src/xmpp/connection.c
index 3853a905..ea3ad010 100644
--- a/src/xmpp/connection.c
+++ b/src/xmpp/connection.c
@@ -5,20 +5,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  * Copyright (C) 2018 - 2023 Michael Vetter <jubalh@idoru.org>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -80,7 +80,7 @@ typedef struct
 } prof_reg_t;
 
 static ProfConnection conn;
-static gchar* profanity_instance_id = NULL;
+static gchar* profanitty_instance_id = NULL;
 static gchar* prof_identifier = NULL;
 
 static void _xmpp_file_logger(void* const userdata, const xmpp_log_level_t level, const char* const area, const char* const msg);
@@ -1111,7 +1111,7 @@ _random_bytes_init(void)
     char* rndbytes_loc;
     GKeyFile* rndbytes;
 
-    rndbytes_loc = files_get_data_path(FILE_PROFANITY_IDENTIFIER);
+    rndbytes_loc = files_get_data_path(FILE_PROFANI_TTY_IDENTIFIER);
 
     if (g_file_test(rndbytes_loc, G_FILE_TEST_EXISTS)) {
         g_chmod(rndbytes_loc, S_IRUSR | S_IWUSR);
@@ -1121,10 +1121,10 @@ _random_bytes_init(void)
     g_key_file_load_from_file(rndbytes, rndbytes_loc, G_KEY_FILE_KEEP_COMMENTS, NULL);
 
     if (g_key_file_has_group(rndbytes, "identifier")) {
-        profanity_instance_id = g_key_file_get_string(rndbytes, "identifier", "random_bytes", NULL);
+        profanitty_instance_id = g_key_file_get_string(rndbytes, "identifier", "random_bytes", NULL);
     } else {
-        profanity_instance_id = get_random_string(10);
-        g_key_file_set_string(rndbytes, "identifier", "random_bytes", profanity_instance_id);
+        profanitty_instance_id = get_random_string(10);
+        g_key_file_set_string(rndbytes, "identifier", "random_bytes", profanitty_instance_id);
 
         gsize g_data_size;
         gchar* g_accounts_data = g_key_file_to_data(rndbytes, &g_data_size, NULL);
@@ -1145,7 +1145,7 @@ _random_bytes_init(void)
 static void
 _random_bytes_close(void)
 {
-    g_free(profanity_instance_id);
+    g_free(profanitty_instance_id);
 }
 
 static void
@@ -1155,12 +1155,12 @@ _compute_identifier(const char* barejid)
     free(prof_identifier);
 
     prof_identifier = g_compute_hmac_for_string(G_CHECKSUM_SHA256,
-                                                (guchar*)profanity_instance_id, strlen(profanity_instance_id),
+                                                (guchar*)profanitty_instance_id, strlen(profanitty_instance_id),
                                                 barejid, strlen(barejid));
 }
 
 const char*
-connection_get_profanity_identifier(void)
+connection_get_profanitty_identifier(void)
 {
     return prof_identifier;
 }
@@ -5,20 +5,20 @@
  * Copyright (C) 2018 - 2023 Michael Vetter <jubalh@idoru.org>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -5,20 +5,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -5,20 +5,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the